@@ -209,8 +209,10 @@ def components(models, wrap_script=True, wrap_plot_info=True, theme=FromCurdoc):
 
     # now convert dict to list, saving keys in the same order
     model_keys = None
+    dict_type = None
     if isinstance(models, dict):
         model_keys = models.keys()
+        dict_type = models.__class__
         values = []
         # don't just use .values() to ensure we are in the same order as key list
         for k in model_keys:
@@ -238,14 +240,13 @@ def components(models, wrap_script=True, wrap_plot_info=True, theme=FromCurdoc):
     # 3) convert back to the input shape
 
     if was_single_object:
-        return script, results[0]
+        result = results[0]
     elif model_keys is not None:
-        result = {}
-        for (key, value) in zip(model_keys, results):
-            result[key] = value
-        return script, result
+        result = dict_type(zip(model_keys, results))
     else:
-        return script, tuple(results)
+        result = tuple(results)
+
+    return script, result
 
 def file_html(models,
               resources,
@@ -312,14 +313,14 @@ def file_html(models,
                                           template=template, template_variables=template_variables)
 
 def json_item(model, target=None, theme=FromCurdoc):
-    ''' Return a JSON block that can be used to embed standalone Bokeh conent.
+    ''' Return a JSON block that can be used to embed standalone Bokeh content.
 
     Args:
         model (Model) :
             The Bokeh object to embed
 
         target (string, optional)
-            A div id to embd the model into. If None, the target id must
+            A div id to embed the model into. If None, the target id must
             be supplied in the JavaScript call.
 
         theme (Theme, optional) :
@@ -354,7 +355,7 @@ def json_item(model, target=None, theme=FromCurdoc):
             .then(function(item) { Bokeh.embed.embed_item(item); })
         </script>
 
-    Alternatively, if is more convenient to suppluy the target div id directly
+    Alternatively, if is more convenient to supply the target div id directly
     in the page source, that is also possible. If `target_id` is omitted in the
     call to this function:
 
