@@ -44,8 +44,8 @@ class TextAnnotation(Annotation):
     '''
 
     render_mode = Enum(RenderMode, default="canvas", help="""
-    Specifies whether the text is rendered as a canvas element or as an
-    css element overlaid on the canvas. The default mode is "canvas".
+    Specifies whether the text is rendered as a canvas element or as a
+    CSS element overlaid on the canvas. The default mode is "canvas".
 
     .. note::
         The CSS labels won't be present in the output using the "save" tool.
@@ -81,6 +81,18 @@ class LegendItem(Model):
     then all data_sources of renderers must be the same.
     """)
 
+    index = Int(default=None, help="""
+    The column data index to use for drawing the representative items.
+
+    If None (the default), then Bokeh will automatically choose an index to
+    use. If the label does not refer to a data column name, this is typically
+    the first data point in the data source. Otherwise, if the label does
+    refer to a column name, the legend will have "groupby" behavior, and will
+    choose and display representative points from every "group" in the column.
+
+    If set to a number, Bokeh will use that number as the index in all cases.
+    """)
+
     @error(NON_MATCHING_DATA_SOURCES_ON_LEGEND_ITEM_RENDERERS)
     def _check_data_sources_on_renderers(self):
         if self.label and 'field' in self.label:
@@ -181,7 +193,7 @@ class Legend(Annotation):
     """)
 
     spacing = Int(3, help="""
-    Amount of spacing (in pixles) between legend entries.
+    Amount of spacing (in pixels) between legend entries.
     """)
 
     items = List(Instance(LegendItem), help="""
@@ -266,7 +278,7 @@ class ColorBar(Annotation):
     """)
 
     formatter = Instance(TickFormatter, default=lambda: BasicTickFormatter(), help="""
-    A TickFormatter to use for formatting the visual appearance of ticks.
+    A ``TickFormatter`` to use for formatting the visual appearance of ticks.
     """)
 
     major_label_overrides = Dict(Either(Float, String), String, default={}, help="""
@@ -278,8 +290,8 @@ class ColorBar(Annotation):
     A continuous color mapper containing a color palette to render.
 
     .. warning::
-        If the `low` and `high` attributes of the ColorMapper aren't set, ticks
-        and tick labels won't be rendered. Additionally, if a LogTicker is
+        If the `low` and `high` attributes of the ``ColorMapper`` aren't set, ticks
+        and tick labels won't be rendered. Additionally, if a ``LogTicker`` is
         passed to the `ticker` argument and either or both of the logarithms
         of `low` and `high` values of the color_mapper are non-numeric
         (i.e. `low=0`), the tick and tick labels won't be rendered.
@@ -383,7 +395,7 @@ class Arrow(Annotation):
     """)
 
     start = Instance('.models.arrow_heads.ArrowHead', default=None, help="""
-    Instance of ArrowHead.
+    Instance of ``ArrowHead``.
     """)
 
     x_end = NumberSpec(help="""
@@ -400,7 +412,7 @@ class Arrow(Annotation):
     """)
 
     end = Instance('.models.arrow_heads.ArrowHead', default=_DEFAULT_ARROW, help="""
-    Instance of ArrowHead.
+    Instance of ``ArrowHead``.
     """)
 
     body_props = Include(LineProps, use_prefix=False, help="""
@@ -520,7 +532,7 @@ class Band(Annotation):
     """)
 
     upper = DistanceSpec(help="""
-    The coordinations of the upper portion of the filled area band.
+    The coordinates of the upper portion of the filled area band.
     """)
 
     base = DistanceSpec(help="""
@@ -528,7 +540,8 @@ class Band(Annotation):
     """)
 
     dimension = Enum(Dimension, default='height', help="""
-    The direction of the band.
+    The direction of the band can be specified by setting this property
+    to "height" (``y`` direction) or "width" (``x`` direction).
     """)
 
     source = Instance(DataSource, default=lambda: ColumnDataSource(), help="""
@@ -694,7 +707,7 @@ class LabelSet(TextAnnotation):
     """)
 
     x_units = Enum(SpatialUnits, default='data', help="""
-    The unit type for the xs attribute. Interpreted as "data space" units
+    The unit type for the ``xs`` attribute. Interpreted as "data space" units
     by default.
     """)
 
@@ -703,7 +716,7 @@ class LabelSet(TextAnnotation):
     """)
 
     y_units = Enum(SpatialUnits, default='data', help="""
-    The unit type for the ys attribute. Interpreted as "data space" units
+    The unit type for the ``ys`` attribute. Interpreted as "data space" units
     by default.
     """)
 
@@ -775,7 +788,7 @@ class PolyAnnotation(Annotation):
     """)
 
     xs_units = Enum(SpatialUnits, default='data', help="""
-    The unit type for the xs attribute. Interpreted as "data space" units
+    The unit type for the ``xs`` attribute. Interpreted as "data space" units
     by default.
     """)
 
@@ -784,7 +797,7 @@ class PolyAnnotation(Annotation):
     """)
 
     ys_units = Enum(SpatialUnits, default='data', help="""
-    The unit type for the ys attribute. Interpreted as "data space" units
+    The unit type for the ``ys`` attribute. Interpreted as "data space" units
     by default.
     """)
 
@@ -814,6 +827,33 @@ class PolyAnnotation(Annotation):
 
     fill_color = Override(default="#fff9ba")
 
+class Slope(Annotation):
+    """ Render a sloped line as an annotation.
+
+    """
+
+    gradient = Float(help="""
+    The gradient of the line, in data units
+    """)
+
+    y_intercept = Float(help="""
+    The y intercept of the line, in data units
+    """)
+
+    x_range_name = String('default', help="""
+    A particular (named) x-range to use for computing screen locations when
+    rendering annotations on the plot. If unset, use the default x-range.
+    """)
+
+    y_range_name = String('default', help="""
+    A particular (named) y-range to use for computing screen locations when
+    rendering annotations on the plot. If unset, use the default y-range.
+    """)
+
+    line_props = Include(LineProps, use_prefix=False, help="""
+    The %s values for the line.
+    """)
+
 class Span(Annotation):
     """ Render a horizontal or vertical line span.
 
@@ -821,7 +861,10 @@ class Span(Annotation):
 
     location = Float(help="""
     The location of the span, along ``dimension``.
-    """)
+
+    Datetime values are also accepted, but note that they are immediately
+    converted to milliseconds-since-epoch.
+    """).accepts(Datetime, convert_datetime_type)
 
     location_units = Enum(SpatialUnits, default='data', help="""
     The unit type for the location attribute. Interpreted as "data space"
@@ -829,7 +872,8 @@ class Span(Annotation):
     """)
 
     dimension = Enum(Dimension, default='width', help="""
-    The direction of the span.
+    The direction of the span can be specified by setting this property
+    to "height" (``y`` direction) or "width" (``x`` direction).
     """)
 
     x_range_name = String('default', help="""
@@ -843,8 +887,8 @@ class Span(Annotation):
     """)
 
     render_mode = Enum(RenderMode, default="canvas", help="""
-    Specifies whether the span is rendered as a canvas element or as an
-    css element overlaid on the canvas. The default mode is "canvas".
+    Specifies whether the span is rendered as a canvas element or as a
+    CSS element overlaid on the canvas. The default mode is "canvas".
 
     .. warning::
         The line_dash and line_dash_offset attributes aren't supported if
@@ -866,11 +910,11 @@ class Title(TextAnnotation):
     """)
 
     vertical_align = Enum(VerticalAlign, default='bottom', help="""
-    Aligment of the text in its enclosing space, *across* the direction of the text.
+    Alignment of the text in its enclosing space, *across* the direction of the text.
     """)
 
     align = Enum(TextAlign, default='left', help="""
-    Aligment of the text in its enclosing space, *along* the direction of the text.
+    Alignment of the text in its enclosing space, *along* the direction of the text.
     """)
 
     offset = Float(default=0, help="""
@@ -958,7 +1002,7 @@ class Tooltip(Annotation):
     """)
 
     show_arrow = Bool(default=True, help="""
-    Whether tooltip's arrow should be showed.
+    Whether tooltip's arrow should be shown.
     """)
 
 # This only exists to prevent a circular import.
@@ -976,15 +1020,15 @@ class Whisker(Annotation):
     """)
 
     lower_head = Instance('.models.arrow_heads.ArrowHead', default=_DEFAULT_TEE, help="""
-    Instance of ArrowHead.
+    Instance of ``ArrowHead``.
     """)
 
     upper = DistanceSpec(help="""
-    The coordinations of the upper end of the whiskers.
+    The coordinates of the upper end of the whiskers.
     """)
 
     upper_head = Instance('.models.arrow_heads.ArrowHead', default=_DEFAULT_TEE, help="""
-    Instance of ArrowHead.
+    Instance of ``ArrowHead``.
     """)
 
     base = DistanceSpec(help="""
@@ -992,7 +1036,8 @@ class Whisker(Annotation):
     """)
 
     dimension = Enum(Dimension, default='height', help="""
-    The direction of the band.
+    The direction of the whisker can be specified by setting this property
+    to "height" (``y`` direction) or "width" (``x`` direction).
     """)
 
     source = Instance(DataSource, default=lambda: ColumnDataSource(), help="""
