@@ -4,11 +4,11 @@ from ..model import Model
 
 class Selection(Model):
     '''
-    A Selection represents a portion of the data in a DataSource, which
+    A Selection represents a portion of the data in a ``DataSource``, which
     can be visually manipulated in a plot.
 
     Selections are typically created by selecting points in a plot with
-    a SelectTool, but can also be programmatically specified.
+    a ``SelectTool``, but can also be programmatically specified.
 
     '''
 
