@@ -7,7 +7,6 @@ from ...core.enums import DateFormat, FontStyle, NumeralLanguage, TextAlign, Rou
 from ...core.has_props import abstract
 from ...core.properties import Bool, Color, Either, Enum, Float, Instance, Int, List, Override, String
 from ...model import Model
-from ...util.deprecation import deprecated
 
 from ..sources import DataSource, CDSView
 
@@ -357,6 +356,8 @@ class HTMLTemplateFormatter(CellFormatter):
     The formatter has access other items in the row via the `dataContext` object passed to the formatter.
     So, for example, if another column in the datasource was named `url`, the template could access it as:
 
+    .. code-block:: jinja
+
         <a href="<%= url %>"><%= value %></a>
 
     To use a different set of template delimiters, pass the appropriate values for `evaluate`, `interpolate',
@@ -364,11 +365,17 @@ class HTMLTemplateFormatter(CellFormatter):
 
     Example: Simple HTML template to format the column value as code.
 
+    .. code-block:: python
+
         HTMLTemplateFormatter(template='<code><%= value %></code>')
 
     Example: Use values from other columns (`manufacturer` and `model`) to build a hyperlink.
 
-        HTMLTemplateFormatter(template='<a href="https:/www.google.com/search?q=<%= manufacturer %>+<%= model %>" target="_blank"><%= value %></a>')
+    .. code-block:: python
+
+        HTMLTemplateFormatter(template=
+            '<a href="https:/www.google.com/search?q=<%= manufacturer %>+<%= model %>" target="_blank"><%= value %></a>'
+        )
 
     '''
     template = String('<%= value %>', help="""
@@ -501,23 +508,6 @@ class DataTable(TableWidget):
 
     '''
 
-    @property
-    def row_header(self):
-        deprecated("DataTable.row_header property is deprecated, use DataTable.index_position instead"\
-                   "In the future, accessing DataTable.row_header will result in an AttributeError.")
-        return self.index_position is not None
-
-    @row_header.setter
-    def row_header(self, val):
-        deprecated("DataTable.row_header property is deprecated, use DataTable.index_position instead."\
-                   "In the future, accessing DataTable.row_header will result in an AttributeError.")
-        if val is True:
-            self.index_position = 0
-        elif val is False:
-            self.index_position = None
-        else:
-            raise ValueError("Expected True or False for DataTable.row_header, got %s" % val)
-
     columns = List(Instance(TableColumn), help="""
     The list of child column widgets.
     """)
@@ -537,7 +527,7 @@ class DataTable(TableWidget):
     """)
 
     reorderable = Bool(True, help="""
-    Allows the reordering of a tables's columns. To reorder a column,
+    Allows the reordering of a table's columns. To reorder a column,
     click and drag a table's header to the desired location in the table.
     The columns on either side will remain in their previous order.
     """)
@@ -581,4 +571,12 @@ class DataTable(TableWidget):
     in the viewport.
     """)
 
+    header_row = Bool(True, help="""
+    Whether to show a header row with column names at the top of the table.
+    """)
+
     height = Override(default=400)
+
+    row_height = Int(25, help="""
+    The height of each row in pixels.
+    """)
