@@ -1,17 +1,164 @@
+#-----------------------------------------------------------------------------
+# Copyright (c) 2012 - 2018, Anaconda, Inc. All rights reserved.
+#
+# Powered by the Bokeh Development Team.
+#
+# The full license is in the file LICENSE.txt, distributed with this software.
+#-----------------------------------------------------------------------------
 ''' Control global configuration options with environment variables.
+A global settings object that other parts of Bokeh can refer to.
 
+
+``BOKEH_BROWSER`` --- What browser to use when opening plots.
+
+  Valid values are any of the browser names understood by the python
+  standard library webbrowser_ module.
+
+``BOKEH_DEV`` --- Whether to use development mode.
+
+  This uses absolute paths to development (non-minified) BokehJS components,
+  sets logging to ``debug``, makes generated HTML and JSON human-readable,
+  etc.
+
+  This is a meta variable equivalent to the following environment variables:
+
+  - ``BOKEH_BROWSER=none``
+  - ``BOKEH_LOG_LEVEL=debug``
+  - ``BOKEH_MINIFIED=false``
+  - ``BOKEH_PRETTY=true``
+  - ``BOKEH_PY_LOG_LEVEL=debug``
+  - ``BOKEH_RESOURCES=absolute-dev``
+  - ``BOKEH_SIMPLE_IDS=true``
+
+  Accepted values are ``yes``/``no``, ``true``/``false`` or ``0``/``1``.
+
+``BOKEH_DOCS_CDN`` --- What version of BokehJS to use when building sphinx.
+
+  See :ref:`bokeh.resources` module reference for full details.
+
+``BOKEH_DOCS_VERSION`` --- What version of Bokeh to show when building sphinx docs locally.
+
+  Useful for re-deployment purposes.
+
+  Set to ``"local"`` to use a locally built dev version of BokehJS.
+
+  .. note::
+      This variable is only used when building documentation from the
+      development version.
+
+``BOKEH_DOCS_CSS_SERVER`` --- Where to get the CSS stylesheet from.
+
+  By default use CSS from bokehplots.com
+
+  .. note::
+      This variable is only used when building documentation from the
+      development version.
+
+  Set to ``"local"`` to use a locally built dev version of BokehJS.
+
+``BOKEH_LOG_LEVEL`` --- The BokehJS console logging level to use.
+
+  Valid values are, in order of increasing severity:
+
+  - ``trace``
+  - ``debug``
+  - ``info``
+  - ``warn``
+  - ``error``
+  - ``fatal``
+
+  The default logging level is ``info``.
+
+  .. note::
+      When running server examples, it is the value of this
+      ``BOKEH_LOG_LEVEL`` that is set for the server that matters.
+
+``BOKEH_MINIFIED`` --- Whether to emit minified JavaScript for ``bokeh.js``.
+
+  Accepted values are ``yes``/``no``, ``true``/``false`` or ``0``/``1``.
+
+``BOKEH_PRETTY`` --- Whether to emit "pretty printed" JSON.
+
+  Accepted values are ``yes``/``no``, ``true``/``false`` or ``0``/``1``.
+
+``BOKEH_PY_LOG_LEVEL`` --- The Python logging level to set.
+
+  As in the JS side, valid values are, in order of increasing severity:
+
+  - ``trace``
+  - ``debug``
+  - ``info``
+  - ``warn``
+  - ``error``
+  - ``fatal``
+  - ``none``
+
+  The default logging level is ``none``.
+
+``BOKEH_RESOURCES`` --- What kind of BokehJS resources to configure.
+
+  For example:  ``inline``, ``cdn``, ``server``. See the
+  :class:`~bokeh.core.resources.Resources` class reference for full details.
+
+``BOKEH_ROOTDIR`` --- Root directory to use with ``relative`` resources.
+
+  See the :class:`~bokeh.resources.Resources` class reference for full
+  details.
+
+``BOKEH_SIMPLE_IDS`` --- Whether to generate human-friendly object IDs.
+
+  Accepted values are ``yes``/``no``, ``true``/``false`` or ``0``/``1``.
+  Normally Bokeh generates UUIDs for object identifiers. Setting this variable
+  to an affirmative value will result in more friendly simple numeric IDs
+  counting up from 1000.
+
+``BOKEH_VERSION`` --- What version of BokehJS to use with ``cdn`` resources.
+
+  See the :class:`~bokeh.resources.Resources` class reference for full details.
+
+.. _webbrowser: https://docs.python.org/2/library/webbrowser.html
 '''
-from __future__ import absolute_import
+#-----------------------------------------------------------------------------
+# Boilerplate
+#-----------------------------------------------------------------------------
+from __future__ import absolute_import, division, print_function, unicode_literals
 
-import codecs
 import logging
+log = logging.getLogger(__name__)
+
+#-----------------------------------------------------------------------------
+# Imports
+#-----------------------------------------------------------------------------
+
+# Standard library imports
+import codecs
 import os
 from os.path import join, abspath, isdir
 
+# External imports
+
+# Bokeh imports
 from .util.paths import ROOT_DIR, bokehjsdir
 
+#-----------------------------------------------------------------------------
+# Globals and constants
+#-----------------------------------------------------------------------------
 
-class Settings(object):
+# __all__ defined at the bottom on the class module
+
+#-----------------------------------------------------------------------------
+# General API
+#-----------------------------------------------------------------------------
+
+#-----------------------------------------------------------------------------
+# Dev API
+#-----------------------------------------------------------------------------
+
+#-----------------------------------------------------------------------------
+# Private API
+#-----------------------------------------------------------------------------
+
+class _Settings(object):
     ''' A class to collect global, overridable Bokeh configuration settings.
 
     '''
@@ -19,6 +166,8 @@ class Settings(object):
     _prefix = "BOKEH_"
     debugjs = False
 
+    # Properties --------------------------------------------------------------
+
     @property
     def _environ(self):
         return os.environ
@@ -34,6 +183,8 @@ class Settings(object):
     def dev(self):
         return self._is_dev
 
+    # Public methods ----------------------------------------------------------
+
     def _dev_or_default(self, default, dev):
         return dev if dev is not None and self._is_dev else default
 
@@ -96,13 +247,6 @@ class Settings(object):
         '''
         return self._get_str("DOCS_VERSION", default)
 
-    def docs_missing_api_key_ok(self, default=False):
-        ''' Control whether a missing google API key should cause the
-        docs build to fail immediately.
-
-        '''
-        return self._get_str("DOCS_MISSING_API_KEY_OK", default)
-
     def minified(self, default=None):
         ''' Set whether Bokeh should use minified BokehJS resources.
 
@@ -236,125 +380,11 @@ class Settings(object):
     def ignore_filename(self):
         return self._get_bool("IGNORE_FILENAME", False)
 
-#: A global settings object that other parts of Bokeh can refer to.
-#:
-#:
-#: ``BOKEH_BROWSER`` --- What browser to use when opening plots.
-#:
-#:   Valid values are any of the browser names understood by the python
-#:   standard library webbrowser_ module.
-#:
-#: ``BOKEH_DEV`` --- Whether to use development mode.
-#:
-#:   This uses absolute paths to development (non-minified) BokehJS components,
-#:   sets logging to ``debug``, makes generated HTML and JSON human-readable,
-#:   etc.
-#:
-#:   This is a meta variable equivalent to the following environment variables:
-#:
-#:   - ``BOKEH_BROWSER=none``
-#:   - ``BOKEH_LOG_LEVEL=debug``
-#:   - ``BOKEH_MINIFIED=false``
-#:   - ``BOKEH_PRETTY=true``
-#:   - ``BOKEH_PY_LOG_LEVEL=debug``
-#:   - ``BOKEH_RESOURCES=absolute-dev``
-#:   - ``BOKEH_SIMPLE_IDS=true``
-#:
-#:  Accepted values are ``yes``/``no``, ``true``/``false`` or ``0``/``1``.
-#:
-#: ``BOKEH_DOCS_CDN`` --- What version of BokehJS to use when building sphinx
-#:   `~bokeh.resources.Resources` class reference for full details.
-#:
-#: ``BOKEH_DOCS_VERSION`` --- What version of Bokeh to show when building sphinx docs locally.
-#:
-#:   Useful for re-deployment purposes.
-#:
-#:   Set to ``"local"`` to use a locally built dev version of BokehJS.
-#:
-#:   .. note::
-#:       This variable is only used when building documentation from the
-#:       development version.
-#:
-#: ``BOKEH_DOCS_CSS_SERVER`` --- Where to get the CSS stylesheet from.
-#:
-#:   By default use CSS from bokehplots.com
-#:
-#:   .. note::
-#:       This variable is only used when building documentation from the
-#:       development version.
-#:
-#:   Set to ``"local"`` to use a locally built dev version of BokehJS.
-#:
-#: ``BOKEH_DOCS_MISSING_API_KEY_OK`` --- Whether the docs build should fail without GOOGLE_API_KEY set.
-#:
-#:   By default, set to `no`, which means the docs build will stop immediately
-#:   if the GOOGLE_API_KEY  environment variable is missing. Set to `yes` to
-#:   enable docs builds to proceed (but with non-functional Google Maps examples).
-#:   Useful for development.
-#:
-#: ``BOKEH_LOG_LEVEL`` --- The BokehJS console logging level to use.
-#:
-#:   Valid values are, in order of increasing severity:
-#:
-#:   - ``trace``
-#:   - ``debug``
-#:   - ``info``
-#:   - ``warn``
-#:   - ``error``
-#:   - ``fatal``
-#:
-#:   The default logging level is ``info``.
-#:
-#:   .. note::
-#:       When running server examples, it is the value of this
-#:       ``BOKEH_LOG_LEVEL`` that is set for the server that matters.
-#:
-#: ``BOKEH_MINIFIED`` --- Whether to emit minified JavaScript for ``bokeh.js``.
-#:
-#:   Accepted values are ``yes``/``no``, ``true``/``false`` or ``0``/``1``.
-#:
-#: ``BOKEH_PRETTY`` --- Whether to emit "pretty printed" JSON.
-#:
-#:   Accepted values are ``yes``/``no``, ``true``/``false`` or ``0``/``1``.
-#:
-#: ``BOKEH_PY_LOG_LEVEL`` --- The Python logging level to set.
-#:
-#:   As in the JS side, valid values are, in order of increasing severity:
-#:
-#:   - ``trace``
-#:   - ``debug``
-#:   - ``info``
-#:   - ``warn``
-#:   - ``error``
-#:   - ``fatal``
-#:   - ``none``
-#:
-#:   The default logging level is ``none``.
-#:
-#: ``BOKEH_RESOURCES`` --- What kind of BokehJS resources to configure.
-#:
-#:   For example:  ``inline``, ``cdn``, ``server``. See the
-#:   :class:`~bokeh.core.resources.Resources` class reference for full details.
-#:
-#: ``BOKEH_ROOTDIR`` --- Root directory to use with ``relative`` resources.
-#:
-#:   See the :class:`~bokeh.resources.Resources` class reference for full
-#:   details.
-#:
-#: ``BOKEH_SIMPLE_IDS`` --- Whether to generate human-friendly object IDs.
-#:
-#:   Accepted values are ``yes``/``no``, ``true``/``false`` or ``0``/``1``.
-#:   Normally Bokeh generates UUIDs for object identifiers. Setting this variable
-#:   to an affirmative value will result in more friendly simple numeric IDs
-#:   counting up from 1000.
-#:
-#: ``BOKEH_VERSION`` --- What version of BokehJS to use with ``cdn`` resources.
-#:
-#:   See the :class:`~bokeh.resources.Resources` class reference for full details.
-#:
-#: .. _webbrowser: https://docs.python.org/2/library/webbrowser.html
-settings = Settings()
-del Settings
+#-----------------------------------------------------------------------------
+# Code
+#-----------------------------------------------------------------------------
+
+settings = _Settings()
 
 if settings.secret_key() is not None:
     if len(settings.secret_key()) < 32:
@@ -364,3 +394,7 @@ if settings.secret_key() is not None:
 if settings.sign_sessions() and settings.secret_key() is None:
     import warnings
     warnings.warn("BOKEH_SECRET_KEY must be set if BOKEH_SIGN_SESSIONS is set to true")
+
+__all__ = (
+  'settings',
+)
