@@ -1,17 +1,18 @@
 from __future__ import absolute_import, print_function
 
 from mock import patch
-import unittest
+import pytest
 
 import logging
 import bokeh.document as document
 from bokeh.application import Application
 from bokeh.application.handlers import FunctionHandler
 from bokeh.client import pull_session, push_session, ClientSession
-from bokeh.document import ModelChangedEvent, TitleChangedEvent, Document
+from bokeh.document import Document
 from bokeh.model import Model
 from bokeh.models import Plot
 from bokeh.core.properties import Int, Instance, Dict, String, Any, DistanceSpec, AngleSpec
+from bokeh.document.events import ModelChangedEvent, TitleChangedEvent
 from tornado import gen
 from tornado.httpclient import HTTPError
 
@@ -34,7 +35,7 @@ class UnitsSpecModel(Model):
 
 logging.basicConfig(level=logging.DEBUG)
 
-class TestClientServer(unittest.TestCase):
+class TestClientServer(object):
 
     def test_minimal_connect_and_disconnect(self):
         application = Application()
@@ -60,10 +61,10 @@ class TestClientServer(unittest.TestCase):
             session._connection._socket.write_message(b"xx", binary=True)
             # connection should now close on the server side
             # and the client loop should end
-            session.loop_until_closed()
+            session.loop_until_closed(suppress_warning=True)
             assert not session.connected
             session.close()
-            session.loop_until_closed()
+            session.loop_until_closed(suppress_warning=True)
             assert not session.connected
 
     def test_connect_with_prefix(self):
@@ -77,158 +78,79 @@ class TestClientServer(unittest.TestCase):
             session.connect()
             assert session.connected
             session.close()
-            session.loop_until_closed()
+            session.loop_until_closed(suppress_warning=True)
 
             session = ClientSession(io_loop = server.io_loop,
                                     websocket_url = ws_url(server))
             session.connect()
             assert not session.connected
             session.close()
-            session.loop_until_closed()
+            session.loop_until_closed(suppress_warning=True)
 
-    def check_http_gets_fail(self, server, host=None):
-        with (self.assertRaises(HTTPError)):
-            http_get(server.io_loop, url(server), host)
-        with (self.assertRaises(HTTPError)):
-            http_get(server.io_loop, url(server) + "autoload.js?bokeh-autoload-element=foo", host)
+    def check_http_gets_fail(self, server):
+        with pytest.raises(HTTPError):
+            http_get(server.io_loop, url(server))
+        with pytest.raises(HTTPError):
+            http_get(server.io_loop, url(server) + "autoload.js?bokeh-autoload-element=foo")
 
-    def check_connect_session_fails(self, server, origin, host=None):
-        with (self.assertRaises(HTTPError)):
+    def check_connect_session_fails(self, server, origin):
+        with pytest.raises(HTTPError):
             websocket_open(server.io_loop,
                            ws_url(server)+"?bokeh-protocol-version=1.0&bokeh-session-id=foo",
-                           origin=origin,
-                           host=host)
+                           origin=origin)
 
-    def check_http_gets(self, server, host=None):
-        http_get(server.io_loop, url(server), host)
-        http_get(server.io_loop, url(server) + "autoload.js?bokeh-autoload-element=foo", host)
+    def check_http_gets(self, server):
+        http_get(server.io_loop, url(server))
+        http_get(server.io_loop, url(server) + "autoload.js?bokeh-autoload-element=foo")
 
-    def check_connect_session(self, server, origin, host=None):
+    def check_connect_session(self, server, origin):
         websocket_open(server.io_loop,
                        ws_url(server)+"?bokeh-protocol-version=1.0&bokeh-session-id=foo",
-                       origin=origin,
-                       host=host)
+                       origin=origin)
 
-    def check_http_ok_socket_ok(self, server, origin=None, host=None):
-        self.check_http_gets(server, host=host)
-        self.check_connect_session(server, origin=origin, host=host)
+    def check_http_ok_socket_ok(self, server, origin=None):
+        self.check_http_gets(server)
+        self.check_connect_session(server, origin=origin)
 
-    def check_http_ok_socket_blocked(self, server, origin=None, host=None):
-        self.check_http_gets(server, host=host)
-        self.check_connect_session_fails(server, origin=origin, host=host)
+    def check_http_ok_socket_blocked(self, server, origin=None):
+        self.check_http_gets(server)
+        self.check_connect_session_fails(server, origin=origin)
 
-    def check_http_blocked_socket_blocked(self, server, origin=None, host=None):
-        self.check_http_gets_fail(server, host=host)
-        self.check_connect_session_fails(server, origin=origin, host=host)
-
-    def test_host_whitelist_success(self):
-        application = Application()
-
-        # succeed no host value with defaults
-        with ManagedServerLoop(application, host=None) as server:
-            self.check_http_ok_socket_ok(server)
-
-        # succeed no host value with port
-        with ManagedServerLoop(application, port=8080, host=None) as server:
-            self.check_http_ok_socket_ok(server)
-
-        # succeed matching host value (localhost)
-        with ManagedServerLoop(application, port=8080, host=["localhost:8080"]) as server:
-            self.check_http_ok_socket_ok(server)
-
-        # succeed matching host value (not localhost)
-        with ManagedServerLoop(application, port=8080, host=["example.com:8080"]) as server:
-            self.check_http_ok_socket_ok(server, host="example.com:8080")
-
-        # succeed matching host value one of multiple
-        with ManagedServerLoop(application, port=8080, host=["bad_host", "localhost:8080"]) as server:
-            self.check_http_ok_socket_ok(server)
-
-        # succeed matching host value with implicit port 80 (note
-        # that the server is in fact on 8080, as if we were behind
-        # a reverse proxy)
-        with ManagedServerLoop(application, port=8080, host=["example.com:80"]) as server:
-            self.check_http_ok_socket_ok(server, host="example.com")
-
-    def test_host_whitelist_failure(self):
-        application = Application()
-
-        # failure bad host with localhost provided as Host
-        with ManagedServerLoop(application, host=["bad_host"]) as server:
-            self.check_http_blocked_socket_blocked(server)
-
-        with ManagedServerLoop(application, host=["bad_host:5006"]) as server:
-            self.check_http_blocked_socket_blocked(server)
-
-        # failure bad host with localhost expected and bad_host provided
-        with ManagedServerLoop(application, port=5006) as server:
-            self.check_http_blocked_socket_blocked(server, host="bad_host")
-
-        with ManagedServerLoop(application, port=5006) as server:
-            self.check_http_blocked_socket_blocked(server, host="bad_host:5006")
-
-        # failure good host, bad port
-        with ManagedServerLoop(application, host=["localhost:80"]) as server:
-            self.check_http_blocked_socket_blocked(server)
-
-        # failure good host, bad default port
-        with ManagedServerLoop(application, host=["localhost"]) as server:
-            self.check_http_blocked_socket_blocked(server)
-
-        # failure with custom port
-        with ManagedServerLoop(application, port=8080, host=["localhost:8081"]) as server:
-            self.check_http_blocked_socket_blocked(server)
-
-        # failure with implicit port 80 in Host when server is on another port
-        with ManagedServerLoop(application, port=5006, host=["example.com:5007"]) as server:
-            self.check_http_blocked_socket_blocked(server, host="example.com")
+    def check_http_blocked_socket_blocked(self, server, origin=None):
+        self.check_http_gets_fail(server)
+        self.check_connect_session_fails(server, origin=origin)
 
     def test_allow_websocket_origin(self):
         application = Application()
 
-        # allow an origin that's an allowed host but not an extra origin
-        with ManagedServerLoop(application, host=None,
-                               allow_websocket_origin=["example.com"]) as server:
-            self.check_http_ok_socket_ok(server, origin=url(server))
-
-        # allow good host and good origin
-        with ManagedServerLoop(application, host=None,
-                               allow_websocket_origin=["example.com"]) as server:
+        # allow good origin
+        with ManagedServerLoop(application, allow_websocket_origin=["example.com"]) as server:
             self.check_http_ok_socket_ok(server, origin="http://example.com:80")
 
-        # allow good host and good origin with port
-        with ManagedServerLoop(application, host=None,
-                               allow_websocket_origin=["example.com:8080"]) as server:
+        # allow good origin with port
+        with ManagedServerLoop(application, allow_websocket_origin=["example.com:8080"]) as server:
             self.check_http_ok_socket_ok(server, origin="http://example.com:8080")
 
-        # allow good host and origin header with an implicit 80
-        with ManagedServerLoop(application, host=None,
-                               allow_websocket_origin=["example.com"]) as server:
+        # allow good origin header with an implicit 80
+        with ManagedServerLoop(application, allow_websocket_origin=["example.com"]) as server:
             self.check_http_ok_socket_ok(server, origin="http://example.com")
 
         # block non-Host origins by default even if no extra origins specified
-        with ManagedServerLoop(application, host=None) as server:
+        with ManagedServerLoop(application) as server:
             self.check_http_ok_socket_blocked(server, origin="http://example.com:80")
 
         # block on a garbage Origin header
-        with ManagedServerLoop(application, host=None) as server:
+        with ManagedServerLoop(application) as server:
             self.check_http_ok_socket_blocked(server, origin="hsdf:::///%#^$#:8080")
 
-        # block good host and bad origin
-        with ManagedServerLoop(application, host=None,
-                               allow_websocket_origin=["example.com"]) as server:
+        # block bad origin
+        with ManagedServerLoop(application, allow_websocket_origin=["example.com"]) as server:
             self.check_http_ok_socket_blocked(server, origin="http://foobar.com:80")
 
-        # block good host and bad origin port
-        with ManagedServerLoop(application, host=None,
-                               allow_websocket_origin=["example.com:8080"]) as server:
+        # block bad origin port
+        with ManagedServerLoop(application, allow_websocket_origin=["example.com:8080"]) as server:
             self.check_http_ok_socket_blocked(server, origin="http://example.com:8081")
 
-        # block on bad host even though the bad host is an allowed origin
-        with ManagedServerLoop(application, host=["bad_host"],
-                               allow_websocket_origin=["bad_host"]) as server:
-            self.check_http_blocked_socket_blocked(server, origin="http://bad_host:80")
-
     def test_push_document(self):
         application = Application()
         with ManagedServerLoop(application) as server:
@@ -257,7 +179,7 @@ class TestClientServer(unittest.TestCase):
             assert results['bar'] == 43
 
             client_session.close()
-            client_session.loop_until_closed()
+            client_session.loop_until_closed(suppress_warning=True)
             assert not client_session.connected
 
     def test_pull_document(self):
@@ -287,7 +209,7 @@ class TestClientServer(unittest.TestCase):
             assert results['bar'] == 43
 
             client_session.close()
-            client_session.loop_until_closed()
+            client_session.loop_until_closed(suppress_warning=True)
             assert not client_session.connected
 
     def test_request_server_info(self):
@@ -308,7 +230,7 @@ class TestClientServer(unittest.TestCase):
             assert info['version_info']['server'] == __version__
 
             session.close()
-            session.loop_until_closed()
+            session.loop_until_closed(suppress_warning=True)
             assert not session.connected
 
     def test_ping(self):
@@ -323,19 +245,19 @@ class TestClientServer(unittest.TestCase):
 
             connection = next(iter(server._tornado._clients))
             expected_pong = connection._ping_count
-            server._tornado.keep_alive() # send ping
+            server._tornado._keep_alive() # send ping
             session.force_roundtrip()
 
-            self.assertEqual(expected_pong, connection._socket.latest_pong)
+            assert expected_pong == connection._socket.latest_pong
 
             # check that each ping increments by 1
-            server._tornado.keep_alive()
+            server._tornado._keep_alive()
             session.force_roundtrip()
 
-            self.assertEqual(expected_pong + 1, connection._socket.latest_pong)
+            assert (expected_pong + 1) == connection._socket.latest_pong
 
             session.close()
-            session.loop_until_closed()
+            session.loop_until_closed(suppress_warning=True)
             assert not session.connected
 
     def test_client_changes_go_to_server(self):
@@ -383,7 +305,7 @@ class TestClientServer(unittest.TestCase):
             assert len(server_session.document.roots) == 0
 
             client_session.close()
-            client_session.loop_until_closed()
+            client_session.loop_until_closed(suppress_warning=True)
             assert not client_session.connected
 
     def test_server_changes_go_to_client(self):
@@ -446,50 +368,9 @@ class TestClientServer(unittest.TestCase):
             assert len(client_session.document.roots) == 0
 
             client_session.close()
-            client_session.loop_until_closed()
+            client_session.loop_until_closed(suppress_warning=True)
             assert not client_session.connected
 
-    def test_io_push_to_server(self):
-        from bokeh.io import output_server, push, curdoc, reset_output
-        application = Application()
-        with ManagedServerLoop(application) as server:
-            reset_output()
-            doc = curdoc()
-            doc.clear()
-
-            client_root = SomeModelInTestClientServer(foo=42)
-
-            session_id = 'test_io_push_to_server'
-            output_server(session_id=session_id,
-                          url=("http://localhost:%d/" % server.port))
-
-            doc.add_root(client_root)
-            push(io_loop=server.io_loop)
-
-            server_session = server.get_session('/', session_id)
-
-            print(repr(server_session.document.roots))
-
-            assert len(server_session.document.roots) == 1
-            server_root = next(iter(server_session.document.roots))
-
-            assert client_root.foo == 42
-            assert server_root.foo == 42
-
-            # Now modify the client document and push
-            client_root.foo = 57
-            push(io_loop=server.io_loop)
-            server_root = next(iter(server_session.document.roots))
-            assert server_root.foo == 57
-
-            # Remove a root and push
-            doc.remove_root(client_root)
-            push(io_loop=server.io_loop)
-            assert len(server_session.document.roots) == 0
-
-            # Clean up global IO state
-            reset_output()
-
     @gen.coroutine
     def async_value(self, value):
         yield gen.moment # this ensures we actually return to the loop
@@ -518,15 +399,15 @@ class TestClientServer(unittest.TestCase):
                 client_session.close()
                 raise gen.Return(5)
 
-            doc.add_timeout_callback(cb, 10)
+            cb_id = doc.add_timeout_callback(cb, 10)
 
-            client_session.loop_until_closed()
+            client_session.loop_until_closed(suppress_warning=True)
 
-            with (self.assertRaises(ValueError)) as manager:
-                doc.remove_timeout_callback(cb)
-            self.assertTrue('already removed' in repr(manager.exception))
+            with pytest.raises(ValueError) as exc:
+                doc.remove_timeout_callback(cb_id)
+            assert 'already removed' in repr(exc.value)
 
-            self.assertDictEqual(dict(a=0, b=1, c=2, d=3, e=4), result.values)
+            assert dict(a=0, b=1, c=2, d=3, e=4) == result.values
 
     def test_client_session_timeout_async_added_before_push(self):
         application = Application()
@@ -546,20 +427,20 @@ class TestClientServer(unittest.TestCase):
                 client_session.close()
                 raise gen.Return(5)
 
-            doc.add_timeout_callback(cb, 10)
+            cb_id = doc.add_timeout_callback(cb, 10)
 
             client_session = push_session(doc,
                                           session_id='test_client_session_timeout_async',
                                           url=url(server),
                                           io_loop=server.io_loop)
 
-            client_session.loop_until_closed()
+            client_session.loop_until_closed(suppress_warning=True)
 
-            with (self.assertRaises(ValueError)) as manager:
-                doc.remove_timeout_callback(cb)
-            self.assertTrue('already removed' in repr(manager.exception))
+            with pytest.raises(ValueError) as exc:
+                doc.remove_timeout_callback(cb_id)
+            assert 'already removed' in repr(exc.value)
 
-            self.assertDictEqual(dict(a=0, b=1, c=2, d=3, e=4), result.values)
+            assert dict(a=0, b=1, c=2, d=3, e=4) == result.values
 
     def test_server_session_timeout_async(self):
         application = Application()
@@ -587,15 +468,15 @@ class TestClientServer(unittest.TestCase):
                 client_session.close()
                 raise gen.Return(5)
 
-            server_session.document.add_timeout_callback(cb, 10)
+            cb_id = server_session.document.add_timeout_callback(cb, 10)
 
-            client_session.loop_until_closed()
+            client_session.loop_until_closed(suppress_warning=True)
 
-            with (self.assertRaises(ValueError)) as manager:
-                server_session.document.remove_timeout_callback(cb)
-            self.assertTrue('already removed' in repr(manager.exception))
+            with pytest.raises(ValueError) as exc:
+                server_session.document.remove_timeout_callback(cb_id)
+            assert 'already removed' in repr(exc.value)
 
-            self.assertDictEqual(dict(a=0, b=1, c=2, d=3, e=4), result.values)
+            assert dict(a=0, b=1, c=2, d=3, e=4) == result.values
 
     def test_client_session_next_tick_async(self):
         application = Application()
@@ -620,15 +501,15 @@ class TestClientServer(unittest.TestCase):
                 client_session.close()
                 raise gen.Return(5)
 
-            doc.add_next_tick_callback(cb)
+            cb_id = doc.add_next_tick_callback(cb)
 
-            client_session.loop_until_closed()
+            client_session.loop_until_closed(suppress_warning=True)
 
-            with (self.assertRaises(ValueError)) as manager:
-                doc.remove_next_tick_callback(cb)
-            self.assertTrue('already removed' in repr(manager.exception))
+            with pytest.raises(ValueError) as exc:
+                doc.remove_next_tick_callback(cb_id)
+            assert 'already removed' in repr(exc.value)
 
-            self.assertDictEqual(dict(a=0, b=1, c=2, d=3, e=4), result.values)
+            assert dict(a=0, b=1, c=2, d=3, e=4) == result.values
 
     def test_client_session_next_tick_async_added_before_push(self):
         application = Application()
@@ -648,20 +529,20 @@ class TestClientServer(unittest.TestCase):
                 client_session.close()
                 raise gen.Return(5)
 
-            doc.add_next_tick_callback(cb)
+            cb_id = doc.add_next_tick_callback(cb)
 
             client_session = push_session(doc,
                                           session_id='test_client_session_next_tick_async',
                                           url=url(server),
                                           io_loop=server.io_loop)
 
-            client_session.loop_until_closed()
+            client_session.loop_until_closed(suppress_warning=True)
 
-            with (self.assertRaises(ValueError)) as manager:
-                doc.remove_next_tick_callback(cb)
-            self.assertTrue('already removed' in repr(manager.exception))
+            with pytest.raises(ValueError) as exc:
+                doc.remove_next_tick_callback(cb_id)
+            assert 'already removed' in repr(exc.value)
 
-            self.assertDictEqual(dict(a=0, b=1, c=2, d=3, e=4), result.values)
+            assert dict(a=0, b=1, c=2, d=3, e=4) == result.values
 
     def test_server_session_next_tick_async(self):
         application = Application()
@@ -689,15 +570,15 @@ class TestClientServer(unittest.TestCase):
                 client_session.close()
                 raise gen.Return(5)
 
-            server_session.document.add_next_tick_callback(cb)
+            cb_id = server_session.document.add_next_tick_callback(cb)
 
-            client_session.loop_until_closed()
+            client_session.loop_until_closed(suppress_warning=True)
 
-            with (self.assertRaises(ValueError)) as manager:
-                server_session.document.remove_next_tick_callback(cb)
-            self.assertTrue('already removed' in repr(manager.exception))
+            with pytest.raises(ValueError) as exc:
+                server_session.document.remove_next_tick_callback(cb_id)
+            assert 'already removed' in repr(exc.value)
 
-            self.assertDictEqual(dict(a=0, b=1, c=2, d=3, e=4), result.values)
+            assert dict(a=0, b=1, c=2, d=3, e=4) == result.values
 
     def test_client_session_periodic_async(self):
         application = Application()
@@ -722,13 +603,13 @@ class TestClientServer(unittest.TestCase):
                 client_session.close()
                 raise gen.Return(5)
 
-            doc.add_periodic_callback(cb, 10)
+            cb_id = doc.add_periodic_callback(cb, 10)
 
-            client_session.loop_until_closed()
+            client_session.loop_until_closed(suppress_warning=True)
 
-            doc.remove_periodic_callback(cb)
+            doc.remove_periodic_callback(cb_id)
 
-            self.assertDictEqual(dict(a=0, b=1, c=2, d=3, e=4), result.values)
+            assert dict(a=0, b=1, c=2, d=3, e=4) == result.values
 
     def test_client_session_periodic_async_added_before_push(self):
         application = Application()
@@ -748,18 +629,18 @@ class TestClientServer(unittest.TestCase):
                 client_session.close()
                 raise gen.Return(5)
 
-            doc.add_periodic_callback(cb, 10)
+            cb_id = doc.add_periodic_callback(cb, 10)
 
             client_session = push_session(doc,
                                           session_id='test_client_session_periodic_async',
                                           url=url(server),
                                           io_loop=server.io_loop)
 
-            client_session.loop_until_closed()
+            client_session.loop_until_closed(suppress_warning=True)
 
-            doc.remove_periodic_callback(cb)
+            doc.remove_periodic_callback(cb_id)
 
-            self.assertDictEqual(dict(a=0, b=1, c=2, d=3, e=4), result.values)
+            assert dict(a=0, b=1, c=2, d=3, e=4) == result.values
 
     def test_server_session_periodic_async(self):
         application = Application()
@@ -787,13 +668,13 @@ class TestClientServer(unittest.TestCase):
                 client_session.close()
                 raise gen.Return(5)
 
-            server_session.document.add_periodic_callback(cb, 10)
+            cb_id = server_session.document.add_periodic_callback(cb, 10)
 
-            client_session.loop_until_closed()
+            client_session.loop_until_closed(suppress_warning=True)
 
-            server_session.document.remove_periodic_callback(cb)
+            server_session.document.remove_periodic_callback(cb_id)
 
-            self.assertDictEqual(dict(a=0, b=1, c=2, d=3, e=4), result.values)
+            assert dict(a=0, b=1, c=2, d=3, e=4) == result.values
 
     def test_lots_of_concurrent_messages(self):
         application = Application()
@@ -806,18 +687,18 @@ class TestClientServer(unittest.TestCase):
             doc.add_root(m3)
             def timeout1():
                 m1.bar += 1
-            doc.add_timeout_callback(timeout1, 1)
+            timeout1_cb_id = doc.add_timeout_callback(timeout1, 1)
             def timeout2():
                 m2.foo +=1
-            doc.add_timeout_callback(timeout2, 3)
+            timeout2_cb_id = doc.add_timeout_callback(timeout2, 3)
             def periodic1():
                 m1.bar += 1
-                doc.remove_timeout_callback(timeout1)
+                doc.remove_timeout_callback(timeout1_cb_id)
                 doc.add_timeout_callback(timeout1, m1.bar % 7)
             doc.add_periodic_callback(periodic1, 3)
             def periodic2():
                 m2.foo += 1
-                doc.remove_timeout_callback(timeout2)
+                doc.remove_timeout_callback(timeout2_cb_id)
                 doc.add_timeout_callback(timeout2, m2.foo % 7)
             doc.add_periodic_callback(periodic2, 1)
 
@@ -843,12 +724,12 @@ class TestClientServer(unittest.TestCase):
             def client_timeout():
                 m = session.document.roots[0]
                 m.name = m.name[::-1]
-            session.document.add_timeout_callback(client_timeout, 3)
+            cb_id = session.document.add_timeout_callback(client_timeout, 3)
 
             def client_periodic():
                 m = session.document.roots[1]
                 m.name = m.name[::-1]
-                session.document.remove_timeout_callback(client_timeout)
+                session.document.remove_timeout_callback(cb_id)
                 session.document.add_timeout_callback(client_timeout, 3)
 
             session.document.add_periodic_callback(client_periodic, 1)
@@ -871,7 +752,7 @@ class TestClientServer(unittest.TestCase):
 
             session.document.on_change(client_on_change)
 
-            session.loop_until_closed()
+            session.loop_until_closed(suppress_warning=True)
 
             assert not session.connected
 
@@ -884,8 +765,6 @@ class TestClientServer(unittest.TestCase):
             assert result['server_connection_count'] == 1
             assert result['server_close_code'] is None
 
-# This isn't in the unittest.TestCase because per-test fixtures
-# don't work there (see note at bottom of https://pytest.org/latest/unittest.html#unittest-testcase)
 def test_client_changes_do_not_boomerang(monkeypatch):
     application = Application()
     with ManagedServerLoop(application) as server:
@@ -928,12 +807,10 @@ def test_client_changes_do_not_boomerang(monkeypatch):
         assert got_angry['result'] is None
 
         client_session.close()
-        client_session.loop_until_closed()
+        client_session.loop_until_closed(suppress_warning=True)
         assert not client_session.connected
         server.unlisten() # clean up so next test can run
 
-# This isn't in the unittest.TestCase because per-test fixtures
-# don't work there (see note at bottom of https://pytest.org/latest/unittest.html#unittest-testcase)
 def test_server_changes_do_not_boomerang(monkeypatch):
     application = Application()
     with ManagedServerLoop(application) as server:
@@ -979,7 +856,7 @@ def test_server_changes_do_not_boomerang(monkeypatch):
         assert got_angry['result'] is None
 
         client_session.close()
-        client_session.loop_until_closed()
+        client_session.loop_until_closed(suppress_warning=True)
         assert not client_session.connected
 
 # this test is because we do the funky serializable_value
@@ -1036,7 +913,7 @@ def test_unit_spec_changes_do_not_boomerang(monkeypatch):
         change_to({ 'value' : 59, 'units' : 'screen' }, { 'value' : 30, 'units' : 'deg' })
 
         client_session.close()
-        client_session.loop_until_closed()
+        client_session.loop_until_closed(suppress_warning=True)
         assert not client_session.connected
         server.unlisten() # clean up so next test can run
 
