@@ -78,22 +78,6 @@ functionality.
 .. automodule:: bokeh.util.paths
   :members:
 
-.. _bokeh.util.platform:
-
-``bokeh.util.platform``
------------------------
-
-.. automodule:: bokeh.util.platform
-  :members:
-
-.. _bokeh.util.plot_utils:
-
-``bokeh.util.plot_utils``
--------------------------
-
-.. automodule:: bokeh.util.plot_utils
-  :members:
-
 .. _bokeh.util.serialization:
 
 ``bokeh.util.serialization``
@@ -118,14 +102,6 @@ functionality.
 .. automodule:: bokeh.util.string
   :members:
 
-.. _bokeh.util.testing:
-
-``bokeh.util.testing``
-----------------------
-
-.. automodule:: bokeh.util.testing
-  :members:
-
 .. _bokeh.util.tornado:
 
 ``bokeh.util.tornado``
@@ -134,6 +110,14 @@ functionality.
 .. automodule:: bokeh.util.tornado
   :members:
 
+  .. _bokeh.util.terminal:
+
+``bokeh.util.terminal``
+-----------------------
+
+.. automodule:: bokeh.util.terminal
+  :members:
+
 .. _bokeh.util.version:
 
 ``bokeh.util.version``
